Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4004)

Unified Diff: chrome/browser/cocoa/tab_controller.h

Issue 184003: Don't show favicons or throbbers for the New Tab page on the Mac.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/nibs/TabView.xib ('k') | chrome/browser/cocoa/tab_controller.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/cocoa/tab_controller.h
===================================================================
--- chrome/browser/cocoa/tab_controller.h (revision 25138)
+++ chrome/browser/cocoa/tab_controller.h (working copy)
@@ -40,8 +40,12 @@
IBOutlet NSMenu* contextMenu_;
IBOutlet NSButton* closeButton_;
+ NSRect originalIconFrame_; // frame of iconView_ as loaded from nib
+ BOOL isIconShowing_; // last state of iconView_ in updateVisibility
BOOL selected_;
TabLoadingState loadingState_;
+ float iconTitleXOffset_; // between left edges of icon and title
+ float titleCloseWidthOffset_; // between right edges of icon and close button
id<TabControllerTarget> target_; // weak, where actions are sent
SEL action_; // selector sent when tab is selected by clicking
}
@@ -53,8 +57,8 @@
@property(assign, nonatomic) SEL action;
// Minimum and maximum allowable tab width. The minimum width does not show
-// the icon or the close box. The selected tab always has at least a close box
-// so it has a different minimum width.
+// the icon or the close button. The selected tab always has at least a close
+// button so it has a different minimum width.
+ (float)minTabWidth;
+ (float)maxTabWidth;
+ (float)minSelectedTabWidth;
@@ -88,7 +92,7 @@
- (NSString *)toolTip;
- (int)iconCapacity;
- (BOOL)shouldShowIcon;
-- (BOOL)shouldShowCloseBox;
+- (BOOL)shouldShowCloseButton;
@end // TabController(TestingAPI)
#endif // CHROME_BROWSER_COCOA_TAB_CONTROLLER_H_
« no previous file with comments | « chrome/app/nibs/TabView.xib ('k') | chrome/browser/cocoa/tab_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698